#! /bin/sh
TestRTInstallDir=/projets/build/Install_OMSR3/releases/TestRealTime.2002.05.21

. $TestRTInstallDir/testrtinit.sh
ATLTGT=$TestRTInstallDir/targets/csolaris6
export ATLTGT
PATH=$ATLTGT/cmd:$PATH

# Compile the test script to C code
attolpreproC "add.ptu" "Tadd.c" -STD_DEFINE="$ATLTGT/ana/atus_c.def"  -incl="." -NOSIMULATION -FAST
if [ $? != 0 ] ; then exit 1; fi

# Compile the code generated
cc -c Tadd.c
if [ $? != 0 ] ; then exit 1; fi

# Instrument the code under test
# Either with attolcc
#attolcc -proc=ret -block=logical -cond=modified -- cc -c add.c
# or manually:
cc -E add.c > add.i
if [ $? != 0 ] ; then exit 1; fi
attolcc1 add.i add_aug.c atct.def -proc=ret -block=logical -cond=modified
if [ $? != 0 ] ; then exit 1; fi
cc -c  add_aug.c -o add.o
if [ $? != 0 ] ; then exit 1; fi

# Compile the TDP
echo "/ATL_WITHOUT_STUDIO/i\\
#define ATL_WITHOUT_STUDIO 1
/define USE_ATU/s/NO/YES/
/define USE_ATC/s/NO/YES/" > sed_file
sed -f sed_file $ATLTGT/lib/products_model.h > products.h
cc -c -I. $ATLTGT/lib/TP.c
if [ $? != 0 ] ; then exit 1; fi

# Link
cc Tadd.o add.o TP.o -o add.exe
if [ $? != 0 ] ; then exit 1; fi

# Execute
./add.exe
if [ $? != 0 ] ; then exit 1; fi

# Split the result file
atlsplit Tadd.rio
mv atltest.rio Tadd.rio

# Extract the coverage results to be used in the Component Testing for C report
attolcov attolcov.tio add.c.fdc -summary=conclusion -cio=Tadd.cio -output=add.txt

# Generate the Test report
attolpostpro Tadd add.rod -cio=Tadd.cio
rod2xrd -oadd.xrd add.rod

# View the reports
studio add.xrd attolcov.tio add.c.fdc

